package com.suman.gmap_place_picker

import android.app.Activity
import android.content.pm.PackageInfo
import androidx.annotation.NonNull
import android.content.pm.PackageManager
import androidx.annotation.UiThread

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import java.math.BigInteger
import java.security.MessageDigest

/** GmapPlacePickerPlugin */
class GmapPlacePickerPlugin(activity: Activity) : FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private lateinit var channel: MethodChannel

    var activity: Activity = actvity

    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val channel = MethodChannel(registrar.messenger(), "gmap_place_picker")
            channel.setMethodCallHandler(GmapPlacePickerPlugin(registrar.activity()))
        }
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        if (call.method == "getPlatformVersion") {
            result.success("Android ${android.os.Build.VERSION.RELEASE}")
        }

        if (call.method == "getSigningCertSha1") {
            try {
                val info: PackageInfo = activity.packageManager.getPackageInfo(call.arguments<String>(), PackageManager.SIGN)
                for (signature in info.signatures) {
                    val messageDigest: MessageDigest = MessageDigest.getInstance("SHA1")
                    messageDigest.update(signature.toByteArray())

                    val bytes: ByteArray = messageDigest.digest()
                    val bigInteger = BigInteger(1, bytes)
                    val hex: String = String.format("%0" + (bytes.size shl 1) + "x", bigInteger)

                    result.success(hex)
                }
            } catch (e: Exception) {
                result.error("ERROR", e.toString(), null)
            }
        } else {
            result.notImplemented()
        }
    }

}
